{% extends "admin/change_list.html" %}
{% load i18n admin_urls static admin_list %}

{% block extrahead %}{{ block.super }}
    <link rel="stylesheet" type="text/css" href="{% static 'edc_dashboard/css/dark_mode.css' %}">
{% endblock %}

{% block extrastyle %}{{ block.super }}

    <script src="https://kit.fontawesome.com/a022b85977.js" crossorigin="anonymous"></script>

{% endblock %}

{% block object-tools-items %}

{% if show_object_tools %}
	{{ block.super }}
{% endif %}

{% endblock object-tools-items %}

{% block usertools %}{% endblock %}

{% block content %}
    {{ block.super }}
{% endblock content %}
