{% extends 'edc_dashboard/bootstrap3/base.html' %}
{% load static %}

{% block main %}


 <div class="container">


    <div class="panel-group">

    <div class="panel panel-success">
      
      <div class="panel-headin
      g"><h4>You are at the subject dashboard</h4></div>      
      <div class="panel-body">{{subject_identifier}}</div>
    </div>
      
    
  </div>
</div> <!-- container -->
{% endblock main %}
