from .model_admin_crf_dashboard_mixin import ModelAdminCrfDashboardMixin
from .model_admin_stacked_inline_mixin import ModelAdminStackedInlineMixin
from .model_admin_subject_dashboard_mixin import ModelAdminSubjectDashboardMixin
