{% extends 'admin/change_form.html' %}

{% load i18n admin_urls static admin_modify %}
{% load edc_dashboard_extras edc_admin_modify %}

{% block extrahead %}{{ block.super }}
    <link rel="stylesheet" type="text/css" href="{% static 'edc_dashboard/css/dark_mode.css' %}">
{% endblock %}


{% block extrastyle %}{{ block.super }}

    <script src="https://kit.fontawesome.com/a022b85977.js" crossorigin="anonymous"></script>

{% endblock %}

{% block field_sets %}

    {% instructions %}

    {% additional_instructions %}

    {% for fieldset in adminform %}
        {#  Custom fieldsets template #}
        {% include "edc_model_admin/admin/fieldset.html" with inline_admin_formsets=inline_admin_formsets %}
    {% endfor %}
{% endblock %}

{# Filter inlines that where already rendered to avoid duplication #}
{% block inline_field_sets %}
    {% for inline_admin_formset in inline_admin_formsets %}
        {% if not inline_admin_formset.opts.insert_after %}
            {% include inline_admin_formset.opts.template %}
        {% endif %}
    {% endfor %}
{% endblock %}

{% block submit_buttons_top %}{% edc_submit_row %}{% endblock %}

{% block submit_buttons_bottom %}

  {% edc_submit_row %}

  {% revision_row %}

{% endblock submit_buttons_bottom %}
