{% extends 'simple_history/object_history_form.html' %}
{% load static %}
{% block extrahead %}{{ block.super }}
    <link rel="stylesheet" type="text/css" href="{% static 'edc_dashboard/css/dark_mode.css' %}">
{% endblock %}
