
{% if additional_instructions %}
    <H5>Additional Instructions:</H5><p>{{ additional_instructions }}</p>
{% endif %}

{% if notification_instructions %}
    <H5>Notifications:</H5><p>{{ notification_instructions }}</p>
    <HR>
{% endif %}
